@@ -37,15 +37,15 @@
 
 #include <QtGui/QGuiApplication>
 #include <QtGui/QOpenGLContext>
-#include <QtGui/QOpenGLPaintDevice>
+#include <QtOpenGL/QOpenGLPaintDevice>
 #include <QtGui/QPainter>
-#include <QtGui/QOpenGLFramebufferObject>
+#include <QtOpenGL/QOpenGLFramebufferObject>
 #include <QtGui/QOffscreenSurface>
 #if defined(Q_OS_OSX)
 #include <qpa/qplatformnativeinterface.h>
 #endif
 
-QT_BEGIN_NAMESPACE_DATAVISUALIZATION
+QT_BEGIN_NAMESPACE
 
 /*!
  * \class QAbstract3DGraph
@@ -60,7 +60,7 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
  * Anti-aliasing is turned on by default on C++, except in OpenGL ES2
  * environments, where anti-aliasing is not supported by Qt Data Visualization.
  * To specify non-default anti-aliasing for a graph, give a custom surface format as
- * a constructor parameter. You can use the convenience function \c QtDataVisualization::qDefaultSurfaceFormat()
+ * a constructor parameter. You can use the convenience function \c qDefaultSurfaceFormat()
  * to create the surface format object.
  *
  * \note QAbstract3DGraph sets window flag \c Qt::FramelessWindowHint on by default. If you want to display
@@ -110,6 +110,8 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
     \value SelectionMultiSeries
            Setting this mode means that items for all series at same position are highlighted, instead
            of just the selected item. The actual selection in the other series doesn't change.
+           When setting this mode flag, one or more of the basic selection flags (\c {SelectionItem},
+           \c {SelectionRow}, or \c SelectionColumn) must also be set.
            Multi-series selection is not supported for Q3DScatter.
 */
 
@@ -186,7 +188,7 @@ QAbstract3DGraph::QAbstract3DGraph(QAbstract3DGraphPrivate *d, const QSurfaceFor
         // Make sure renderable type is correct
         surfaceFormat.setRenderableType(QSurfaceFormat::DefaultRenderableType);
     } else {
-        surfaceFormat = qDefaultSurfaceFormat();
+        surfaceFormat = qDefaultSurfaceFormat(true);
     }
 
     d_ptr->m_context = new QOpenGLContext(this);
@@ -435,6 +437,16 @@ void QAbstract3DGraph::clearSelection()
     d_ptr->m_visualController->clearSelection();
 }
 
+/*!
+ * Returns whether the \a series has already been added to the graph.
+ *
+ * \since 6.3
+ */
+bool QAbstract3DGraph::hasSeries(QAbstract3DSeries *series) const
+{
+    return d_ptr->m_visualController->hasSeries(series);
+}
+
 /*!
  * Adds a QCustom3DItem \a item to the graph. Graph takes ownership of the added item.
  *
@@ -1193,4 +1205,4 @@ QImage QAbstract3DGraphPrivate::renderToImage(int msaaSamples, const QSize &imag
     return image;
 }
 
-QT_END_NAMESPACE_DATAVISUALIZATION
+QT_END_NAMESPACE
